@@ -3,6 +3,7 @@ from redis.exceptions import AuthenticationError
 from rq import Queue
 from sqlalchemy import create_engine
 from sqlalchemy.orm import Session, declarative_base
+import telnyx
 
 import os
 import logging
@@ -17,6 +18,7 @@ class Config:
     REDIS_DB = os.environ.get("REDIS_DB", 0)
     BOT_KEY = os.environ.get("BOT_KEY")
     assert BOT_KEY, "BOT_KEY is not specified"
+    #! If don't need => then remove
     SIP_PASSWORD = os.environ.get("SIP_PASSWORD")
     assert SIP_PASSWORD, "SIP_PASSWORD is not specified"
     SIP_USERNAME = os.environ.get("SIP_USERNAME")
