@@ -1,9 +1,10 @@
 from datetime import timedelta, datetime
+import time
 from voip_shifts.bot import bot
 from rq.job import get_current_job
 from sqlalchemy import and_, select
 from tzlocal import get_localzone
-import re
+import telnyx
 
 import subprocess
 
@@ -29,8 +30,8 @@ class Shifts():
         self.skip = skip
         self.source_phone = source_phone
         self.destination_phone = destination_phone
-        self.on_shift_call = f"1+++++++{self.client_id}+++++"
-        self.off_shift_call = f"2+++++++{self.client_id}+++++{self.service_id}+++++++1+++0+++++"
+        self.on_shift_call = f"1WWWWWWW{self.client_id}WWWWW"
+        self.off_shift_call = f"2WWWWWWW{self.client_id}WWWWW{self.service_id}WWWWWWW1WWW0WWWWW"
 
     def is_callable(self, datetime_:datetime) -> bool:
         if datetime.now(get_localzone()) < datetime_ + timedelta(minutes=10):
@@ -52,27 +53,19 @@ class Shifts():
             return None
 
         if Config.MODE == "prod":
-            subprocess.run(
-                [
-                    "./call-prog",
-                    "-r",
-                    self.sip_server,
-                    "-u",
-                    self.username,
-                    "-p",
-                    self.password,
-                    "-n",
-                    self.source_phone,
-                    "-t",
-                    f"{self.destination_phone}@" + self.sip_server,
-                    "-d",
-                    f"+4++++++{self.employee_id}++++++++2++++++{type_of_call}",
-                    "-T",
-                    f"{self.get_printable_time(datetime_)}_{self.client_id}",
-                    "-P",
-                    "9001",
-                ]
-            )
+            call = telnyx.Call.create(connection_id="2021741919184356464", to=f"+1{self.destination_phone}", from_=f"+1{self.source_phone}")
+            time.sleep(5)
+            call.record_start(format="mp3", channels="single")
+            time.sleep(5)
+            call.send_dtmf(digits=f"W4WWWWWW{self.employee_id}WWWWWWWW2WWWWWW{type_of_call}")
+            if type_of_call is self.on_shift_call:
+                time.sleep(55)
+            else:
+                time.sleep(75)
+            try:
+                call.hangup()
+            except Exception as e:
+                log.info(f"hangup error with {e}")
         else:
             log.info(f"""./call-prog, -r {self.sip_server} -u {self.username} -p {self.password} -n \
                     {self.source_phone} -t {self.destination_phone}@{self.sip_server} -d \
